package com.sun.xml.internal.ws.model.wsdl;

import com.sun.xml.internal.ws.api.model.wsdl.WSDLModel;
import com.sun.xml.internal.ws.api.model.wsdl.WSDLPort;
import com.sun.xml.internal.ws.api.model.wsdl.WSDLExtension;
import java.util.List;
import org.xml.sax.Locator;
import com.sun.istack.internal.Nullable;
import java.util.Iterator;
import com.sun.istack.internal.NotNull;
import java.util.LinkedHashMap;
import javax.xml.stream.XMLStreamReader;
import com.sun.xml.internal.ws.api.model.wsdl.editable.EditableWSDLModel;
import com.sun.xml.internal.ws.api.model.wsdl.editable.EditableWSDLPort;
import java.util.Map;
import javax.xml.namespace.QName;
import com.sun.xml.internal.ws.api.model.wsdl.editable.EditableWSDLService;

public final class WSDLServiceImpl extends AbstractExtensibleImpl implements EditableWSDLService
{
    private final QName name;
    private final Map<QName, EditableWSDLPort> ports;
    private final EditableWSDLModel parent;
    
    public WSDLServiceImpl(XMLStreamReader xsr, EditableWSDLModel parent, QName name) {
        super(xsr);
        this.parent = parent;
        this.name = name;
        this.ports = new LinkedHashMap();
    }
    
    @NotNull
    public EditableWSDLModel getParent() {
        return this.parent;
    }
    
    public QName getName() {
        return this.name;
    }
    
    public EditableWSDLPort get(QName portName) {
        return (EditableWSDLPort)this.ports.get(portName);
    }
    
    public EditableWSDLPort getFirstPort() {
        if (this.ports.isEmpty()) {
            return null;
        }
        return (EditableWSDLPort)this.ports.values().iterator().next();
    }
    
    public Iterable<EditableWSDLPort> getPorts() {
        return this.ports.values();
    }
    
    @Nullable
    public EditableWSDLPort getMatchingPort(QName portTypeName) {
        for (EditableWSDLPort port : this.getPorts()) {
            QName ptName = port.getBinding().getPortTypeName();
            assert ptName != null;
            if (ptName.equals(portTypeName)) {
                return port;
            }
            continue;
        }
        return null;
    }
    
    public void put(QName portName, EditableWSDLPort port) {
        if (portName == null || port == null) {
            throw new NullPointerException();
        }
        this.ports.put(portName, port);
        return;
    }
    
    public void freeze(EditableWSDLModel root) {
        for (EditableWSDLPort port : this.ports.values()) {
            port.freeze(root);
        }
    }
}
